## Copyright (C) 2018 jdonoghue
## 
## This program is free software: you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation, either version 3 of the License, or
## (at your option) any later version.
## 
## This program is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
## 
## You should have received a copy of the GNU General Public License
## along with this program.  If not, see
## <https://www.gnu.org/licenses/>.

## -*- texinfo -*- 
## @deftypefn {} {@var{retval} =} scanForArduinos (@var{maxCount)})
## Scan system for arduino boards and return at most @var{maxCount} of them as a cell array in @var{retval}.
##
## Each cell value of the cell array will contain a structure with values of:
## * port - the serial port the arduino is connected to
## * board - the board type of the arduino
## 
## if maxCount is not specified, or is a less than 1, the function will return as many
## arduino boards as it can detect.
##
## @seealso{arduino}
## @end deftypefn

function arduinos = scanForArduinos (maxCount, typestr)

  arduinos = {};
  ARDUINO_INIT_COMMAND = 1;

  if nargin > 2
    print_usage ();
  elseif nargin > 1
    typestr = "";
  else
    maxCount = 0;
    typestr = "";
  endif

  if ~isnumeric (maxCount)
    error ('scanForArduinos expected maxCount to be a number');
  endif
  if ~ischar (typestr)
    error ('scanForArduinos expected typestr to be a baord type');
  endif

  # get list of serial ports to try
  ports = instrhwinfo('serial');

  for i = 1:numel(ports)
    try
      s = {};
      unwind_protect
        if isunix
          portname = ["/dev/" ports{i}];
        else
          portname = ports{i};
        endif
        s = serial(portname, 9600, 1);
        pause(2);
     
        hdr = uint8([ hex2dec("A5") 0 ARDUINO_INIT_COMMAND 0]);
        len = srl_write(s, hdr);
        [tmpdataOut, tmpdataSize] = srl_read (s, 4);
        if tmpdataSize == 4 && tmpdataOut(1) == hex2dec("A5") && tmpdataOut(3) == ARDUINO_INIT_COMMAND
          expectlen =  tmpdataOut(4);

	  # TODO: need extract what need from the return
          [dataout, datasize] = srl_read (s, expectlen);

	  # init returns the following info
          sig = (uint32(dataout(1))*256*256) + (uint32(dataout(2))*256) + uint32(dataout(3));
          board = dataout(4);
          voltref = dataout(5);
   
	  # TODO: check board match if specified
	  info = {};
          info.port = portname;
	  info.board = "uno"; 
          arduinos{end+1} = info;
	  if numel (arduinos) == maxCount
            break;
	  endif
        endif

      unwind_protect_cleanup
        if !isempty(s)
	  srl_close(s);
        endif
      end_unwind_protect

    catch err
      % do nothing
    end_try_catch
  endfor
endfunction
